<?php

use Behat\Behat\Context\Context;
use Behat\Behat\Hook\Scope\AfterStepScope;
use Behat\Gherkin\Node\PyStringNode;
use Behat\Gherkin\Node\TableNode;
use \Behat\MinkExtension\Context\MinkContext;
use \Behat\Mink\Element\NodeElement;

/**
 * Defines application features from the specific context.
 */
class FeatureContext extends MinkContext implements Context
{
    /**
     * Initializes context.
     *
     * Every scenario gets its own context instance.
     * You can also pass arbitrary arguments to the
     * context constructor through behat.yml.
     */
    public function __construct()
    {
    }

    /**
     * @BeforeScenario
     */
    public function beforeScenarioResize()
    {
        if ($this->getSession()->getDriver() instanceof \Behat\Mink\Driver\Selenium2Driver)
        {
            $this->getSession()->resizeWindow(1980, 1080, 'current');
        }
    }

    /**
     * @When I wait :seconds seconds
     *
     * @param mixed $seconds
     */
    public function iWaitSecondsForRedirect($seconds)
    {
        $this->getSession()->wait(
            $seconds * 1000
        );
    }

    /**
     * @BeforeScenario @login
     */
    public function login()
    {
        $session = $this->getSession();
        $session->visit("https://build53.invorbereitung.de/login.php");
        $page = $session->getPage();
        $page->find("named", array("id", "username"))->setValue('##USERNAME##');
        $page->find("named", array("id", "password"))->setValue('##PASSWORD##');
        $page->find("named", array("button", "Login"))->click();
    }

    /**
     * @AfterStep
     */
    public function takeScreenShotAfterFailedStep(AfterStepScope $scope)
    {
        if (99 === $scope->getTestResult()->getResultCode())
        {
            try {
                $screenshotData = $this->getSession()->getDriver()->getScreenshot();
            } catch (\Behat\Mink\Exception\UnsupportedDriverActionException $e) {
            } catch (\Behat\Mink\Exception\DriverException $e) {
            }

            file_put_contents('/tmp/test_'.uniqid().'.png', $screenshotData);
        }
    }


    /**
     * @Then I click link :link
     *
     * @param $link
     *
     * @throws \Behat\Mink\Exception\ElementNotFoundException
     */
    public function clickLink($link)
    {
        $link = $this->fixStepArgument($link);

        $this->getSession()->getPage()->clickLink($link);
    }
}
